@@ -1,7 +1,7 @@
 package Log::ger::App;
 
-our $DATE = '2020-11-02'; # DATE
-our $VERSION = '0.015'; # VERSION
+our $DATE = '2020-11-11'; # DATE
+our $VERSION = '0.016'; # VERSION
 
 # IFUNBUILT
 # use strict;
@@ -10,6 +10,9 @@ our $VERSION = '0.015'; # VERSION
 
 our $DEBUG = defined($ENV{LOG_GER_APP_DEBUG}) ? $ENV{LOG_GER_APP_DEBUG} : 0;
 
+# last import args
+our @IMPORT_ARGS;
+
 sub _set_level {
     my $name = shift;
 
@@ -189,6 +192,9 @@ sub import {
     die "Unknown argument(s): ".join(", ", sort keys %args)
         if keys %args;
 
+    # save, for those who want to check or modify
+    @IMPORT_ARGS = @_;
+
     require Log::ger::Output;
     Log::ger::Output->set('Composite', %conf);
 }
@@ -208,7 +214,7 @@ Log::ger::App - An easy way to use Log::ger in applications
 
 =head1 VERSION
 
-version 0.015
+version 0.016
 
 =head1 SYNOPSIS
 
@@ -360,6 +366,11 @@ configuration.
 Default is false. If set to true, will show more details about how log level,
 etc is set.
 
+=head2 @IMPORT_ARGS
+
+Will be set with the last aguments passed to import(), for informational
+purposes.
+
 =head1 ENVIRONMENT
 
 =head2 LOG_GER_APP_DEBUG
